@@ -5,9 +5,9 @@ import sys
 
 from ..util_core.v2ray import restart
 from ..util_core.writer import NodeWriter, GroupWriter
-from ..util_core.group import Vmess, Socks, Mtproto, SS
-from ..util_core.selector import GroupSelector, ClientSelector
-from ..util_core.utils import StreamType, stream_list, is_email, clean_iptables, random_email, ColorStr, readchar, random_port, port_is_use
+from ..util_core.group import Vmess, Socks, Mtproto, SS, Vless, Trojan, Xtls
+from ..util_core.selector import GroupSelector, ClientSelector, CommonSelector
+from ..util_core.utils import StreamType, stream_list, is_email, clean_iptables, random_email, ColorStr, readchar, random_port, port_is_use, xtls_flow
 
 @restart(True)
 def new_port(new_stream=None):
@@ -70,7 +70,7 @@ def new_user():
         pass
     else:
         email = ""
-        if type(group.node_list[0]) == Vmess: 
+        if type(group.node_list[0]) in (Vmess, Vless, Trojan, Xtls): 
             while True:
                 is_duplicate_email=False
                 remail = random_email()
@@ -95,6 +95,17 @@ def new_user():
 
             nw = NodeWriter(group.tag, group.index)
             info = {'email': email}
+            if type(group.node_list[0]) == Trojan:
+                password = input(_("please input trojan user password: "))
+                if password == "":
+                    print(_("password is null!!"))
+                    exit(-1)
+                info['password'] = password
+            elif type(group.node_list[0]) == Xtls:
+                flow_list = xtls_flow()
+                print("")
+                flow = CommonSelector(flow_list, _("please select xtls flow type: ")).select()
+                info['flow'] = flow
             nw.create_new_user(**info)
             return True
 
